@@ -13,6 +13,7 @@
 # obs:
 #
 
+from __future__ import print_function
 import numpy as np
 
 from gsw.utilities import loadmatbunch
@@ -20,13 +21,13 @@ from gsw.utilities import loadmatbunch
 data_ver = 'v3_0'
 gsw_data = loadmatbunch('gsw_data_%s.mat' % data_ver, masked=False)
 
-print(('Data version number: %s' % gsw_data.version_number))
-print(('Data version date: %s' % gsw_data.version_date))
+print('Data version number: %s' % gsw_data.version_number)
+print('Data version date: %s' % gsw_data.version_date)
 
 # Delta SA Atlas.
 ref_table = dict()
 for k in gsw_data:
-    if k == 'gsw_cv' or k == '#refs#' or k == 'gsw_demo_data':
+    if k == u'gsw_cv' or k == u'#refs#' or k == 'gsw_demo_data':
         pass
     else:
         ref_table[k] = gsw_data[k]
